import random
from typing import TypedDict, Dict

class DialogueEntry(TypedDict):
    zh: str
    ja: str

ENTRY: Dict[str, DialogueEntry] = {
    "1-2": {
        "zh": "比黑色更黑、比黑暗更暗的漆黑\n在此寄托吾真红的金光吧！\n觉醒之时已然来临\n真理坠入无缪境界\n化为无形扭曲 显现吧！\n跃动吧！起舞吧！欢涌吧！\n吾之力量洪流渴望崩坏\n渴望无可匹敌的崩坏！\n将万象化作灰烬\n自深渊降临吧！\n这正是人类最强威力的攻击手段\n这就是究极攻击魔法！\n『Explosion！！』",
        "ja": "黒より黒く闇より暗き漆黒に\n我が深紅の混淆を望みたもう\n覚醒のとき来たれり\n無謬の境界に落ちし理\n無行の歪みとなりて現出せよ！\n踊れ 踊れ 踊れ\n我が力の奔流に望むは崩壊 なり\n並ぶ者なき崩壊なり\n万象等しく灰塵に帰し\n深淵より来たれ！\nこれが人類最大の威力の攻撃手段\nこれこそが究極の攻撃魔法\n「エクスプロージョン！」"
    },
    "1-3": {
        "zh": "被光明笼罩的漆黑啊\n身披夜之衣的爆炎啊\n以红魔族之名 显现原初崩坏吧！\n于终焉王国之地\n引渡力量本源之物啊!\n在吾之前展现吧！\n『Explosion！』",
        "ja": "光に覆われし漆黒よ\n夜を纏いし爆炎よ\n紅魔の名のもとに原初の崩壊を顕現す\n終焉の王国の地に、\n力の根源を隠匿せし者\n我が前に統べよ！\n「エクスプロージョン！」"
    },
    "1-4": {
        "zh": "赤红之黑炎\n万界之君王\n天地之火咆哮之时\n吾乃万象升温之理\n崩坏破坏之别名！\n业火铁锤降临吾身！\n『Explosion！！』",
        "ja": "紅き黒炎、万界の王\n天地の法を敷衍すれど、\n我は万象昇温の理\n崩壊破壊の別名なり\n永劫の鉄槌は我がもとに下れ！\n「エクスプロージョン！」"
    },
    "1-6": {
        "zh": "吾名惠惠\n红魔族第一的魔法师\n兼爆裂魔法的操纵者\n好好见识我的力量吧！\n『Explosion！』",
        "ja": "我が名はめぐみん\n紅魔族随一の魔法の使い手にして、\n爆裂魔法を操りし者\n我が力、見るがいい！\n「エクスプロージョン！」"
    },
    "1-7": {
        "zh": "以吾真红之流动\n颠覆白色之世界\n『Explosion！』",
        "ja": "我が深紅の流出を以て、\n白き世界を覆さん！\n「エクスプロージョン！」"
    },
    "1-10-1": {
        "zh": "比黑更黑、比暗更暗的漆黑\n在此寄托吾真红的金光吧\n觉醒之时已然来临\n真理坠入无缪境界\n化为无形扭曲显现\n『Explosion！』",
        "ja": "黒より黒く闇より暗き漆黒に、\n我が真紅の混淆を望みたもう\n覚醒の時来たれり無謬の境界に堕ちし理、\n無暁の歪みと成りて現出せよ\n「エクスプロージョン！」"
    },
    "1-10-2": {
        "zh": "被光明笼罩的漆黑\n藏于夜色中的爆炎\n其它的暂且不提、说到爆裂魔法\n我不想输给任何人！\n要上了\n吾之究极破坏魔法——\n『Explosion！！』",
        "ja": "光に覆われし漆黒よ\n夜を纏いし爆炎よ\nほかはともかく、爆裂魔法のことに関しては\n私は誰にも負けたくないのです！\n行きます！\n我が究極の破壊魔法、\n「エクスプロージョン！」"
    },
    "2-5": {
        "zh": "现世空蝉悄然侵入反逆天楼\n于吾身前造访乃是寂静神雷\n时机已到！\n现在，\n以狂热之力惊醒沉寂，\n显现吧！贯穿一切！\n『Explosion！』",
        "ja": "空蝉に忍び寄る叛逆の摩天楼\n我が前に訪れた静寂なる神雷\n時は来た！今、\n眠りから目覚め、\n我が狂気を以て現界せよ！\n穿て！\n「エクスプロージョン！」"
    },
    "2-10": {
        "zh": "爆走、爆走、爆走\n最高最强大的魔法\操控爆裂魔法之人\n吾名惠惠\n吾之一击\n是献给同伴之爱的盲目旋律\n将苏生埋葬于彼岸\n\n展现最强大的鼓动！\n可悲的野兽啊\n和红色黑焰同调\n化为血潮补偿你的罪过吧！\n穿刺吧！\n『Explosion！！』",
        "ja": "爆走、爆走、爆走\n最高最強にして最大の魔法\n爆裂魔法の使い手\n我が名はめぐみん\n我に許されし一撃は\n同胞の愛にも似た盲目を奏で\n塑性を脆性へと葬り去る\n強き鼓動を享受する！\n\n哀れな獣よ\n紅き黒炎と同調し\n血潮となりて償いたまえ！\n穿て！\n「エクスプロージョン！」"
    },
    "2-11": {
        "zh": "环绕于我的乖逸精灵\n深渊的血肉狂然咆哮\n现在\n成为红色波动的一部分吧！\n穿刺吧！\n『Explosion！』",
        "ja": "我を取り巻く戒律のるつぼよ\n深淵の血肉が咆哮する\n今紅き波動の一部となれ\n穿て\n「エクスプロージョン！」"
    },
    "movie-1": {
        "zh": "吾乃惠惠\n乃至高全能的支配者\n立于魔力高天之上、施与号令之人！\n...\n降临吧、降临吧\n烈焰的军阵啊\n回应吾之召唤、显现你的力量吧！\n『Explosion...\n诶？？（惠惠震惊.jpg）』",
        "ja": "我が名はめぐみん\n我は至高にして全能の支配者\nその天なる力の疊より命ずる者なり\n繰るべし、繰るべし\n炎の軍勢よ\n我が望みに応じ\nその力を示せ\nエクスプロージョン"
    },
    "movie-2": {
        "zh": "吾乃悠悠！\n红魔族第一、最强的魔法使！\n\n吾乃惠惠！\n红魔族第一、最强的魔法使！\n悠悠那时挽回了我研习爆裂魔法的机会\n所以才有了今天的我！\n\n因为有惠惠这位劲敌\n我才一路成长至今！\n『Light of Saber！！』\n\n振翅吧风暴！嘶吼吧烈焰！\n爆裂魔法是无限的梦想！\n将一切不可能化为现实\n最强的魔法！\n『Explosion！！』",
        "ja": "我が名はゆんゆん\n紅魔族随一にして、最高の魔法使い！\n\n我が名はめぐみん\n紅魔族随一にして、最強の魔法使い！\n\nゆんゆんがあの時、私に爆裂魔法への道を行かせてくれたから\n\nめぐみんがいてくれたから、ライバルとして今日まで来れた！\n「ライト・オブ・セイバー！」\n\n吹けよ嵐、響けよ爆炎\n爆裂魔法はロマンなんです\nどんな不可能も可能にする、最強の魔法なんです！\n「エクスプローーージョン！」"
    },
    "movie-3": {
        "zh": "吾乃米米！\n红魔族第一的魔性妹妹\n凌驾魔王军干部之人！\n(*^ - ^*)",
        "ja": "我が名はこめっこ\n紅魔族随一の魔性の妹！\n魔王軍幹部より強き者！！\n(*^ - ^*)"
    },
}

MESSAGES = {
    "zh": {
        "吟唱上限": "Explosion 次数已达上限，请使用 /补魔 恢复魔力！",
        "补魔上限": "今日补魔次数已用尽，请明日再来吧！",
        "补魔成功": "魔力已恢复，尽情享受爆炸吧！",
        "help": (
            "吾名惠惠！红魔族第一的魔法师，爆裂魔法的操纵者！"
            "\n指令列表："
            "\n/来一发 - 施展爆裂魔法"
            "\n/补魔 - 恢复施展次数"
            "\n/爆裂魔法 help - 显示帮助"
            "\n每日可补魔{}次 x 可施放{}次"
        )
    },
    "ja": {
        "吟唱上限": "Explosion の使用回数が上限に達しました。/replenish で魔力を回復してください！",
        "补魔上限": "今日の補魔回数は使い切りました。明日また来てください！",
        "补魔成功": "魔力が回復しました。爆発を楽しんでください！",
        "help": (
            "我が名はめぐみん、红魔族随一の魔法の使い手にして！"
            "\nコマンド一覧："
            "\n/explosion - 爆裂魔法を発動"
            "\n/replenish - 使用回数を回復"
            "\n/explosion help - ヘルプを表示"
            "\n毎日補魔{}回、放出{}回可能"
        )
    }
}

def get_random_entry(lang: str) -> tuple[str, str]:
    """随机获取词条（含key）"""
    key = random.choice(list(ENTRY.keys()))
    return key, ENTRY[key][lang]

def get_i18n_tips(key: str, lang: str) -> str:
    """获取指定语种提示"""
    return MESSAGES[lang][key]
